==> 2.4.zip: rsyncui/README_FR.md <==
# RsyncUI

client Rsync - QT5 - KDE

# Compilation:

$ qmake
$ make
$ make install

# Lancement

Lancez le programme en cliquant sur l'icone ou en tapant dans un terminal:
$ RsyncUI

# Utilisation

Entrez le nom du serveur et le numéro port dans les champs de saisie dédiés.(par défaut le port est 873)
La liste des services s'affiche dans le cadre services, cliquez sur celui que vous voulez consulter.
La liste des dossiers et des fichiers s'affichent.
Un clic gauche sur un fichier l'ajoute à la file des téléchargements, sur un dossier, ça l'ouvre.
Un clic droit sur un dossier ouvre un menu contextuel permettant de télécharger le dossier entier.
Une notification s'affiche lors du début, de la fin, et lorsque l'on stoppe un téléchargement. 
Le gadget de fermeture ferme la fenêtre mais ne quitte pas l'application, pour afficher à nouveau la fenêtre, cliquez sur l'icône dans la boite à miniatures.

## File de téléchargement

Cliquez sur un fichier pour le supprimer de la file et une fenêtre de confirmation apparait.

## Barre d'outils

1er icône: Changer le dossier de destination
    Permet de changer le dossier de téléchargement par défaut pour chaque service de chaque serveur.

2ème icône: Paramètres de l'application
 - Limite de bande passante
    Permet de limiter le débit de téléchargement en Ko, Mo, Go, To et Po.
    Si la valeur est 0 alors pas de limite de la vitesse de téléchargement.
 - Affichage de la barre d'outils
    Permet de choisir le style d'affichage des icônes de la barre d'outils
 - Enregistrement automatique
    Enregistre automatiquement la liste des téléchargements en cours.(activé par défaut)
3ème icône: À propos
    Affiche les propriétés de l'application.
4ème icône: À propos de QT   
5 ème icône: Quitter
    Permet de quitter le programme.

==> 2.12.3.zip: rsyncui/README_FR.md <==
# RsyncUI

client Rsync - QT5 - KDE

# Compilation:

$ qmake
$ make
$ make install

# Lancement

Lancez le programme en cliquant sur l'icone ou en tapant dans un terminal:
$ RsyncUI

# Utilisation

Entrez le nom du serveur et le numéro port dans les champs de saisie dédiés.(par défaut le port est 873)
La liste des services s'affiche dans le cadre services, cliquez sur celui que vous voulez consulter.
La liste des dossiers et des fichiers s'affichent.
Un clic gauche sur un fichier l'ajoute à la file des téléchargements, sur un dossier, ça l'ouvre.
Un clic droit sur un dossier ouvre un menu contextuel permettant de télécharger le dossier entier.
Une notification s'affiche lors du début, de la fin, et lorsque l'on stoppe un téléchargement. 
Le gadget de fermeture ferme la fenêtre mais ne quitte pas l'application, pour afficher à nouveau la fenêtre, cliquez sur l'icône dans la boite à miniatures.
Un identifiant et un mot de passe lorsqu'un service est protégé par mot de passe, celui-ci est enregistré dans le portefeuille système(gome-keyring ou kwallet)

## File de téléchargement

Cliquez sur un fichier pour le supprimer de la file et une fenêtre de confirmation apparait.

## Barre d'outils

1er icône: Changer le dossier de destination
 - Permet de changer le dossier de téléchargement par défaut pour chaque service de chaque serveur.
2éme icône: Services cachés
 - Permet de configurer un service caché.
    Il faut donner le nom du service et le mot de passe si besoin.
3ème icône: Paramètres de l'application
 - Limite de bande passante
    Permet de limiter le débit de téléchargement en Ko, Mo, Go, To et Po.
    Si la valeur est 0 alors pas de limite de la vitesse de téléchargement.
 - Affichage de la barre d'outils
    Permet de choisir le style d'affichage des icônes de la barre d'outils
 - Enregistrement automatique
    Enregistre automatiquement la liste des téléchargements en cours.(activé par défaut)
3ème icône: À propos
 - Affiche les propriétés de l'application.
4ème icône: À propos de QT   
5ème icône: Quitter
    Permet de quitter le programme.
